@@ -15,18 +15,18 @@ if (sys.modules.has_key('gnome_sudoku') and
     # If the installed_mode attribute is not set, then we are
     # importing from something other than the gnome-sudoku script; we
     # assume anyone importing in this way is doing testing etc.
-    APP_DATA_DIR = os.path.join('/home/thomas/svn/test5', 'share') 
+    APP_DATA_DIR = os.path.join('/home/thomas/newsvn/test', 'share') 
     IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
     LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
     GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
     BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
     PUZZLE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku','puzzles')    
 else:
-    APP_DATA_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'data') 
-    IMAGE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'images')
+    APP_DATA_DIR = os.path.join('/home/thomas/newsvn/gnome-games', 'gnome-sudoku', 'data') 
+    IMAGE_DIR = os.path.join('/home/thomas/newsvn/gnome-games', 'gnome-sudoku', 'images')
     LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
-    GLADE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'glade')
-    BASE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'data')
+    GLADE_DIR = os.path.join('/home/thomas/newsvn/gnome-games', 'gnome-sudoku', 'glade')
+    BASE_DIR = os.path.join('/home/thomas/newsvn/gnome-games', 'gnome-sudoku', 'data')
     PUZZLE_DIR = BASE_DIR
 
 DOMAIN = 'gnome-games'
@@ -37,7 +37,7 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.21.91"
+VERSION = "2.21.92"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2008, Thomas M. Hinkle'
